@@ -25,6 +25,8 @@ faux_prompt <- function(
   prompt=getOption("prompt"), continue=getOption("continue")
 ) {
   res <- character()
+  old.opt <- options(warn=1L)
+  on.exit(options(old.opt))
   repeat {
     res.parse <- tryCatch({
         res <- paste0(res, read_line(prompt), if(length(res)) '\n' else "")
